aboutsummaryrefslogtreecommitdiff
path: root/src/simplewallet/simplewallet.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/simplewallet/simplewallet.cpp')
-rw-r--r--src/simplewallet/simplewallet.cpp10
1 files changed, 2 insertions, 8 deletions
diff --git a/src/simplewallet/simplewallet.cpp b/src/simplewallet/simplewallet.cpp
index e6400d4ba..5292580d7 100644
--- a/src/simplewallet/simplewallet.cpp
+++ b/src/simplewallet/simplewallet.cpp
@@ -1651,13 +1651,8 @@ bool simple_wallet::submit_multisig_main(const std::vector<std::string> &args, b
return false;
}
- // actually commit the transactions
- for (auto &ptx: txs.m_ptx)
- {
- m_wallet->commit_tx(ptx);
- success_msg_writer(true) << tr("Transaction successfully submitted, transaction ") << get_transaction_hash(ptx.tx) << ENDL
- << tr("You can check its status by using the `show_transfers` command.");
- }
+ // actually commit or save the transactions
+ commit_or_save(txs.m_ptx, m_do_not_relay);
}
catch (const std::exception &e)
{
@@ -7750,7 +7745,6 @@ bool simple_wallet::sweep_single(const std::vector<std::string> &args_)
}
commit_or_save(signed_tx.ptx, m_do_not_relay);
- success_msg_writer(true) << tr("Money successfully sent, transaction: ") << get_transaction_hash(ptx_vector[0].tx);
}
catch (const std::exception& e)
{